#ifndef GRAPHICS_WINDOW_H
#define GRAPHICS_WINDOW_H

/*
**  window.h
**
**  (C) Copyright 2003-2004 Rocklyte Systems.
**      All Rights Reserved.
*/

#ifndef MAIN_H
#include <pandora/main.h>
#endif

/*****************************************************************************
** Window structure
*/

struct Window {
   OBJECT_HEADER               /* Class header */
   struct Render *Drawable;    /* The window drawable */
   LONG      Flags;            /* Special options */
   LONG      InsideBorder;     /* Set to TRUE to draw a border at the edges of the window */
   LONG      Center;           /* Set to TRUE if the window position should be centered */
   LONG      Minimise;         /* Set to TRUE to enable the minimise gadget */
   LONG      Maximise;         /* Set to TRUE to enable the maximise gadget */
   LONG      MoveToBack;       /* Set to TRUE to enable the movetoback gadget */
   LONG      Close;            /* Set to TRUE to enable the close gadget */
   LONG      Quit;             /* If TRUE, a quit message will be sent when the window is closed */
   LONG      RestoreX;         /* X coordinate to restore when reversing the maximise operation */
   LONG      RestoreY;         /* Y coordinate to restore when reversing the maximise operation */
   LONG      RestoreWidth;     /* Width to restore when reversing the maximise operation */
   LONG      RestoreHeight;    /* Height to restore when reversing the maximise operation */
   LONG      Hide;             /* Set to TRUE to hide the window on opening (script usage only) */
   LONG      Focus;            /* Set to TRUE if the window should get the focus whenever it is shown */
   LONG      Screen;           /* Set to TRUE to open the window in full screen mode */
   OBJECTID  TitleID;          /* Refers to the text object that controls the window title */
   OBJECTID  MinimiseID;       /* The drawable that represents the minimise gadget */
   OBJECTID  MaximiseID;       /* The drawable that represents the maximise gadget */
   OBJECTID  MoveToBackID;     /* The drawable that represents the move-to-back gadget */
   OBJECTID  CloseID;          /* The drawable that represents the close gadget */
   OBJECTID  MenubarID;        /* The drawable that represents the menubar */
   LONG      ScreenMargin;     /* Minimum allowable margin value when in screen mode */
   LONG      ResizeFlags;
   LONG      ResizeBorder;     /* Pixel width of the resize border */
   LONG      NoMargins;        /* Special: May only be set from the window template script */
   OBJECTID  CanvasID;

   PRIVATE_FIELDS
   OBJECTID  DrawableID;       /* Drawable region created by the window object */
   OBJECTID  InputID;          /* Keyboard object to use for receiving input */
   OBJECTPTR TemplateXML;
   OBJECTPTR Resize;           /* Resize object */
   OBJECTID  ProgramID;        /* The task that created the window */
   BYTE      KeyboardChannel;  /* TRUE if the keyboard is active */
   BYTE      Shown;
   UBYTE     Title[120];       /* Window title */
   UBYTE     Icon[60];         /* Window icon */
   UBYTE     Menu[180];        /* Location of an XML menu file */
   STRING    *LocalArgs;       /* Argument table (created via calls to SetUnlistedField()) */
   LONG      TotalArgs;        /* Total number of arguments in the LocalArgs table */
   STRING    ScriptArgs;       /* Allocated block of arguments presented as a string, for script usage */
};

#define WNF_MANUALCLOSE 0x00000001 /* Developer controls what happens when the close gadget is used */
#define WNF_DISABLED    0x00000002 /* Disable on creation */
#define WNF_SMARTLIMITS 0x00000004 /* Use automated limits to prevent the window from leaving the display */
#define WNF_BACKGROUND  0x00000008 /* Force a background to be drawn if the window opens in full-screen mode */
#define WNF_VIDEO       0x00000010 /* Request that the window be buffered in video RAM instead of software RAM */
#define WNF_NOMARGINS   0x00000020 /* Eliminate unnecessary margin space at the window edges */

/*****************************************************************************
** Window methods
*/

#define MT_MaximiseWindow   -1
#define MT_MinimiseWindow   -2
#define MT_CloseWindow      -3

struct mtMaximiseWindow {
   LONG Toggle;
};

#endif /* GRAPHICS_WINDOW_H */
